@@ -4,7 +4,8 @@ import typing as t
 from pydantic import BaseModel
 
 P = t.ParamSpec("P")
-R = t.TypeVar("R", covariant=True)
+R = t.TypeVar("R")
+R_co = t.TypeVar("R_co", covariant=True)
 PydanticModel = t.TypeVar("PydanticModel", bound=BaseModel)
 
 
